@@ -17,8 +17,17 @@
 -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 --
 
--- KULRICE-6452
 
-drop table krms_cntxt_vld_event_t;
-drop sequence krms_cntxt_vld_event_s;
-rename krms_cntxt_term_spec_prereq_s to krms_cntxt_vld_term_spec_s;
+--
+-- KULRICE-10251: Maintain KRMS Agenda permission has confusing and unused permission detail
+--
+
+DELETE FROM krim_perm_attr_data_t
+WHERE attr_val = 'KRMS_TEST' AND perm_id =
+  (
+    SELECT
+      perm_id
+    FROM krim_perm_t
+    WHERE nm = 'Maintain KRMS Agenda' AND nmspc_cd = 'KR-RULE-TEST'
+  );
+
